@@ -154,8 +154,8 @@ around run => sub ( $orig, $self, $req ) {
 
     my $loader_path = {
         q[*]                       => q[.],
-        Ext                        => '/static/sencha/ext/src/',
-        'Ext.ux'                   => '/static/sencha/ext/ux/',
+        Ext                        => '/static/extjs/src/',
+        'Ext.ux'                   => '/static/extjs/ux/',
         Pcore                      => '/static/extjs/pcore/',
         $self->{ext_app_namespace} => $self->{path},
     };
